//This is a sample script of cropland extent classification.
//Depending on the study areas, area boundaries, imageries, and training samples are adjusted, but the sample logic applies.
//Ying Zhong / 09/24/2017

//Define study area boundaries:
var geometry41 = ee.FeatureCollection([ee.Feature(
            ee.Geometry.Polygon(
                [[[-78.7939453125, 13.325484885597936],
                  [-78.8818359375, 1.7575368113083254],
                  [-67.0166015625, 1.054627942275887],
                  [-67.4560546875, 13.410994034321702]]]),
            {
              "system:index": "0"
            })]);

//Import training samples for croplands and non-croplands. 
//The training samples are shipped as shapefiles, and they can be uploaded as fusion tables, and imported using codes below:
var train_noncrop41 = ee.FeatureCollection('ft:FUSION_TABLE_ID');
var train_cropland41 = ee.FeatureCollection('ft:FUSION_TABLE_ID');
var train = [train_noncrop41,train_cropland41];
var TrainingSamples = ee.FeatureCollection(train);

//Import Landsat imageries bands:
var image = ee.Image("users/SouthAmericaLandsat/Tile41_season1"),
    image2 = ee.Image("users/SouthAmericaLandsat/Tile41_season2"),
    image3 = ee.Image("users/SouthAmericaLandsat/Tile41_season3"),
    image4 = ee.Image("users/SouthAmericaLandsat/Tile41_season4"),
    image5 = ee.Image("users/SouthAmericaLandsat/Tile41_season5"),
    image6 = ee.Image("users/SouthAmericaLandsat/Tile41_season6");

//Overall mask:
var Mask41 = ee.Image("users/SouthAmericaLandsat/41_OtherVeg");
var Mask = Mask41.eq(1);
var Mask = Mask.updateMask(Mask)
          .updateMask(image.select(0))
          .updateMask(image2.select(0))
          .updateMask(image3.select(0))
          .updateMask(image4.select(0))
          .updateMask(image5.select(0))
          .updateMask(image6.select(0));
//Apply cClassification mask
var image = image.updateMask(Mask);
var image2 = image2.updateMask(Mask);
var image3 = image3.updateMask(Mask);
var image4 = image4.updateMask(Mask);
var image5 = image5.updateMask(Mask);
var image6 = image6.updateMask(Mask);

//Load Slope band and mask it
var elev = ee.Image("USGS/SRTMGL1_003");
var slope = ee.Terrain.slope(elev).updateMask(Mask);

//Calculate NDVI sd
var NDVIcollection = ee.ImageCollection([image.select('NDVI'),
                image2.select('NDVI'),
                image3.select('NDVI'),
                image4.select('NDVI'),
                image5.select('NDVI'),
                image6.select('NDVI')]);
var NDVI_sd = NDVIcollection.reduce(ee.Reducer.stdDev());      

//Composite all training bands together
var Variables = ee.Image.cat([image,image2,image3,image4,image5,image6,NDVI_sd,slope]);

// Get the values for all pixels in each polygon in the training.
var training = Variables.sampleRegions({
    collection: TrainingSamples,
  properties: ['class'],
  scale: 30
}).filter(ee.Filter.neq('blue',null));

//build classifier
var classifier = ee.Classifier.randomForest(600,0,1,0.5,true).train(training, 'class');

//classify the whole landscape
var classified = Variables.classify(classifier);
var palette =['ff2609', '0ff71b'];
Map.addLayer (classified,{min:0,max:1,palette:palette},'cropland classes')

//calculate training accuracy
var trainAccuracy = classifier.confusionMatrix();
print('Resubstitution error matrix: ', trainAccuracy);
print('Training overall accuracy: ', trainAccuracy.accuracy());

//Export the classified image
Export.image.toDrive({
  image: classified,
  description: 'classified',
  scale: 30,
  region: geometry41,
  maxPixels:5000000000000
});

      